hive-rss.source

The rss ingestion source: one document per item of one feed, for memory ingest source source=rss rss-url=.... The ingest pipeline chunks, embeds and stores what this returns; the scheduler does not go through it.

The `rss` ingestion source: one document per item of one feed, for
`memory ingest source source=rss rss-url=...`. The ingest pipeline chunks,
embeds and stores what this returns; the scheduler does not go through it.
raw docstring

documentsclj

(documents url feed)

Result of one ingestion document per item of feed, fetched from url.

Result of one ingestion document per item of `feed`, fetched from `url`.
sourceraw docstring

paramsclj

source

source-idclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries