The rss ingestion source: one document per item of one feed, for
memory ingest source source=rss rss-url=.... The ingest pipeline chunks,
embeds and stores what this returns; the scheduler does not go through it.
The `rss` ingestion source: one document per item of one feed, for `memory ingest source source=rss rss-url=...`. The ingest pipeline chunks, embeds and stores what this returns; the scheduler does not go through it.
(documents url feed)Result of one ingestion document per item of feed, fetched from url.
Result of one ingestion document per item of `feed`, fetched from `url`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |